#!/usr/local/bin/perl

require 'codeconv.pl';
require 'getopts.pl';

sub usage {
	print STDERR "rklist2rkpl - convert Roma-Kana table to Perl header\n";
	print STDERR " % rklist2rkpl -h -s rktable > rkheader.pl\n";
	print STDERR " -h: Hiragana \n";
	print STDERR " -s: Shift JIS \n";
	exit;
}

$options = join(' ',@ARGV);

print <<EOF;
#
# This file is created by "rklist2rkpl $options".  Don't edit!!
#
EOF

&usage unless &Getopts('hs');
&usage unless $rktable = shift;
&usage unless -f $rktable;

open(table, "nkf -e $rktable |") || die "Can't invoke NKF";
while(<table>){
	chop;
	next if /^#/;
	($r,$k) = split(/\s+/);

	$k = &strconv($k);

	$rk{$r} = $k;

	@kr = split(/,/,$kr{$k});
	push(@kr,$r);
	$kr{$k} = join(',',@kr);
}

$s = &hexdump(&strconv(''));
print <<EOF;
\$romakana'str_n = "$s";
EOF

$s = &hexdump(&strconv(''));
print <<EOF;
\$romakana'str_tsu = "$s";
EOF

print "%romakana'rk = (\n";
for $r (sort keys %rk){
	print "\t\"$r\",\t\"",&hexdump($rk{$r}),"\",\n";
}
print ");\n\n";

print "%romakana'kr = (\n";
for $k (sort keys %kr){
	print "\t\"",&hexdump($k),"\",\t\"$kr{$k}\",\n";
}
print ");\n\n";

sub strconv {
	local($_) = @_;
	if($opt_h){
		$s = '';
		while($_ ne ''){
			if(($h,$l) = /^([\x80-\xff])(.)/){
				s/^..//;
				if(ord($h) == 0xa5){
					$h = "\xa4";
				}
				$s .= $h.$l;
			}
			else {
				s/^.//;
				$s .= $&;
			}
		}
		$_ = $s;
	}
	if($opt_s){
		$_ = &jis2sjis(&ujis2jis($_));
	}
	$_;
}

sub hexdump {
	local($_) = @_;
	local($s) = '';
	while(s/^.//){
		$s .= sprintf("\\x%02x",ord($&));
	}
	$s;
}

